.. currentmodule:: h5netcdf

.. _api:

#################
New API reference
#################

This page provides an auto-generated summary of h5netcdf's new API.

.. autosummary::
   :toctree: generated/

   File
   File.create_group
   File.create_variable
   File.resize_dimension
   Group
   Dimension
   Variable
   CompoundType
   EnumType
   VLType
